@@ -649,6 +649,26 @@ def cli():
                         help="output file, (default STDOUT)",
                         type=argparse.FileType('w'),
                         default=sys.stdout)
+    parser.add_argument('--from',
+                        dest='informat',
+                        choices=('notebook', 'markdown'),
+                        help=("format to convert from, defaults to markdown "
+                              "or file extension"))
+    parser.add_argument('--to',
+                        dest='outformat',
+                        choices=('notebook', 'markdown'),
+                        help=("format to convert to, defaults to notebook "
+                              "or file extension"))
+    parser.add_argument('--reverse',
+                        action='store_true',
+                        help=("alias for --from notebook --to markdown"))
+    parser.add_argument('--run',
+                        action='store_true',
+                        help=("run the notebook using runipy"))
+    parser.add_argument('--strip',
+                        action='store_true',
+                        dest='strip_outputs',
+                        help=("strip output cells"))
     parser.add_argument('--precode',
                         nargs='+',
                         default=[],
@@ -670,26 +690,6 @@ def cli():
                         action='store_false',
                         dest='magic',
                         help=("disable code magic."))
-    parser.add_argument('--strip',
-                        action='store_true',
-                        dest='strip_outputs',
-                        help=("strip output cells"))
-    parser.add_argument('--from',
-                        default='markdown',
-                        dest='informat',
-                        choices=('notebook', 'markdown'),
-                        help=("format to convert from, defaults to markdown"))
-    parser.add_argument('--to',
-                        default='notebook',
-                        dest='outformat',
-                        choices=('notebook', 'markdown'),
-                        help=("format to convert to, defaults to notebook"))
-    parser.add_argument('--reverse',
-                        action='store_true',
-                        help=("alias for --from notebook --to markdown"))
-    parser.add_argument('--run',
-                        action='store_true',
-                        help=("run the notebook using runipy"))
     parser.add_argument('--code_block',
                         help=("choose to match only 'fenced' or 'indented' "
                               "code blocks or give a regular expression to "
@@ -741,8 +741,11 @@ def cli():
         args.informat = 'notebook'
         args.outformat = 'markdown'
 
-    Reader, rargs, rkwargs = readers[args.informat]
-    Writer, wargs, wkwargs = writers[args.outformat]
+    informat = args.informat or ftdetect(args.input_file.name) or 'markdown'
+    outformat = args.outformat or ftdetect(args.output.name) or 'notebook'
+
+    Reader, rargs, rkwargs = readers[informat]
+    Writer, wargs, wkwargs = writers[outformat]
     reader = Reader(*rargs, **rkwargs)
     writer = Writer(*wargs, **wkwargs)
 
@@ -753,5 +756,20 @@ def cli():
         writer.write(notebook, op)
 
 
+def ftdetect(filename):
+    """Determine if filename is markdown or notebook,
+    based on the file extension.
+    """
+    _, extension = os.path.splitext(filename)
+    md_exts = ['.md', '.markdown', '.mkd', '.mdown', '.mkdn', '.Rmd']
+    nb_exts = ['.ipynb']
+    if extension in md_exts:
+        return 'markdown'
+    elif extension in nb_exts:
+        return 'notebook'
+    else:
+        return None
+
+
 if __name__ == '__main__':
     cli()
